diff -Nur postfix.orig/postfix-2.0.16-20031026-multiline-greeting.patch postfix/postfix-2.0.16-20031026-multiline-greeting.patch
--- postfix.orig/postfix-2.0.16-20031026-multiline-greeting.patch	1970-01-01 01:00:00.000000000 +0100
+++ postfix/postfix-2.0.16-20031026-multiline-greeting.patch	2004-08-25 21:06:25.000000000 +0200
@@ -0,0 +1,180 @@
+
+        smtpd - SMTP Multiline Banner support
+        =====================================
+
+This patch allows a system administrator to configure Postfix and provide
+system information to a remote administrator by adding information to the
+SMTP banner his server provides.  The SMTP banner normally only provides
+one line of output, and this patch allows the output to be split over
+several lines.
+
+The URL for the patch is:
+
+    * Patch for Postfix 2.1, 2.0 and 2.0.x-yyyymmdd:
+      ftp://ftp.WL0.org/SOURCES/postfix-2.0.16-20031026-multiline-greeting.patch
+
+To use this patch /etc/postfix/main.cf must be setup as follows:
+
+# The smtpd_banner parameter specifies the text that follows the 220
+# status code in the SMTP greeting banner. Some people like to see
+# the mail version advertised. By default, Postfix shows no version. 
+#
+# You MUST specify the $myhostname at the start of the text. When
+# the SMTP client sees its own hostname at the start of an SMTP
+# greeting banner it will report a mailer loop. That's better than
+# having a machine meltdown.
+#
+# Additionally when the smtpd_banner patch is applied multiple lines
+# can be sent in the smtpd_banner, each new line separated by the
+# sequence "\n" as shown below.
+#
+smtpd_banner = $myhostname ESMTP $mail_name\n
+	\n
+	System Info: This is a Postfix mail server\n
+	.            running a multiline SMTP greeting patch\n
+	\n
+	Further Info: See http://www.postfix.org\n
+	\n
+	Site Contact: John Smith, Postmaster\n
+	Email:        <postmaster@test.com>\n
+	Telephone:    +1-123-456-7890 \n
+	Please don't send me SPAM here - we don't like it
+
+# This produces the following SMTP greeting:
+#
+# 220-mail.test.com ESMTP Postfix
+# 220-
+# 220-System Info: This is a Postfix mail server
+# 220-.            running a multiline SMTP greeting patch
+# 220-
+# 220-Further Info: See http://www.postfix.org
+# 220-
+# 220-Site Contact: John Smith, Postmaster
+# 220-Email:        <postmaster@test.com>
+# 220-Telephone:    +1-123-456-7890
+# 220-
+# 220 Please don't send me SPAM here - we don't like it
+#
+# patch follows below:
+
+diff -ur postfix-2.0.16-20031026.orig/src/smtpd/smtpd.c postfix-2.0.16-20031026.patched/src/smtpd/smtpd.c
+--- postfix-2.0.16-20031026.orig/src/smtpd/smtpd.c	Wed Oct 22 18:58:55 2003
++++ postfix-2.0.16-20031026.patched/src/smtpd/smtpd.c	Wed Nov 12 16:47:46 2003
+@@ -1808,7 +1808,7 @@
+ 	    && (state->access_denied = smtpd_check_client(state)) != 0) {
+ 	    smtpd_chat_reply(state, "%s", state->access_denied);
+ 	} else {
+-	    smtpd_chat_reply(state, "220 %s", var_smtpd_banner);
++	    smtpd_chat_reply_multiline(state, 220, var_smtpd_banner);
+ 	}
+ 
+ 	for (;;) {
+diff -ur postfix-2.0.16-20031026.orig/src/smtpd/smtpd_chat.c postfix-2.0.16-20031026.patched/src/smtpd/smtpd_chat.c
+--- postfix-2.0.16-20031026.orig/src/smtpd/smtpd_chat.c	Sat Jul  5 17:28:32 2003
++++ postfix-2.0.16-20031026.patched/src/smtpd/smtpd_chat.c	Wed Nov 12 17:51:15 2003
+@@ -14,6 +14,11 @@
+ /*	SMTPD_STATE *state;
+ /*	char	*format;
+ /*
++/*	void	smtpd_chat_reply_multiline(state, smtp_reply_code, format, ...)
++/*	SMTPD_STATE *state;
++/*	int	smtp_reply_code;
++/*	char	*format;
++/*
+ /*	void	smtpd_chat_notify(state)
+ /*	SMTPD_STATE *state;
+ /*
+@@ -31,6 +36,11 @@
+ /*	When soft_bounce is enabled, all 5xx (reject) reponses are
+ /*	replaced by 4xx (try again).
+ /*
++/*	smtpd_chat_reply_multiline() formats a server reply, sends it to
++/*	the client, and appends a copy to the SMTP transaction log.
++/*	The reply can contain embedded "\n"s which will be treated as
++/*	separators in a multiline reply.
++/*
+ /*	smtpd_chat_notify() sends a copy of the SMTP transaction log
+ /*	to the postmaster for review. The postmaster notice is sent only
+ /*	when delivery is possible immediately. It is an error to call
+@@ -61,6 +71,8 @@
+ #include <time.h>
+ #include <stdlib.h>			/* 44BSD stdarg.h uses abort() */
+ #include <stdarg.h>
++#include <string.h>
++#include <ctype.h>
+ 
+ /* Utility library. */
+ 
+@@ -180,6 +192,61 @@
+ 	vstream_longjmp(state->client, SMTP_ERR_TIME);
+     if (vstream_ferror(state->client))
+ 	vstream_longjmp(state->client, SMTP_ERR_EOF);
++}
++
++/* trim_line - remove trailing whitespace and return a pointer to the first */
++/* non-space char in the string.  Based on TRIM() in ../util/dict.c         */
++/* WARNING: this function is DESTRUCTIVE.                                   */
++
++static char *trim_line( char *line ) {
++    char *p;
++
++    for (p=line + strlen(line); p > line && ISSPACE(p[-1]); p--);
++	*p = 0;
++
++    while ( ISSPACE(*line) )
++	++line;
++
++    return ( line );
++}
++
++/* smtpd_chat_reply_multiline - convert multline string into seperate */
++/* lines, sending each one to smtpd_chat_reply()                      */
++
++#define LINE_SEPARATOR "\n"
++
++void smtpd_chat_reply_multiline(SMTPD_STATE *state, int smtp_reply_code, char *format,...)
++{
++    va_list ap;
++    char    *line, *line2;     /* one line (of the multiline) reply */
++    size_t   size;             /* size of a single line             */
++    static VSTRING *temp_line; /* SMTP reply before unescapeing     */
++    static VSTRING *multiline; /* SMTP reply after unescaping       */
++
++    /* First-time intialization. */
++    if (!temp_line)
++	temp_line = vstring_alloc(512);
++    if (!multiline)
++	multiline = vstring_alloc(512);
++
++    va_start(ap, format);
++    vstring_vsprintf(temp_line, format, ap);
++    va_end(ap);
++
++    /* unescape lines with "\\n", converting them to "\n" */
++    unescape( multiline, STR(temp_line) );
++
++    line = STR(multiline);
++    while ( (size = strcspn(line, LINE_SEPARATOR)) < strlen(line) ) {
++       *(line + size) = 0;
++
++       line2 = trim_line(line);
++       smtpd_chat_reply(state, "%03d-%s", smtp_reply_code, line2);
++
++       line += size + 1;
++    }
++    line2 = trim_line(line);
++    smtpd_chat_reply(state, "%03d %s", smtp_reply_code, line2);
+ }
+ 
+ /* print_line - line_wrap callback */
+diff -ur postfix-2.0.16-20031026.orig/src/smtpd/smtpd_chat.h postfix-2.0.16-20031026.patched/src/smtpd/smtpd_chat.h
+--- postfix-2.0.16-20031026.orig/src/smtpd/smtpd_chat.h	Sat Nov 18 11:37:30 2000
++++ postfix-2.0.16-20031026.patched/src/smtpd/smtpd_chat.h	Wed Nov 12 16:47:46 2003
+@@ -15,6 +15,7 @@
+ extern void smtpd_chat_reset(SMTPD_STATE *);
+ extern void smtpd_chat_query(SMTPD_STATE *);
+ extern void PRINTFLIKE(2, 3) smtpd_chat_reply(SMTPD_STATE *, char *, ...);
++extern void smtpd_chat_reply_multiline(SMTPD_STATE *, int, char *, ...);
+ extern void smtpd_chat_notify(SMTPD_STATE *);
+ 
+ /* LICENSE
diff -Nur postfix.orig/postfix.spec postfix/postfix.spec
--- postfix.orig/postfix.spec	2004-07-27 17:09:27.000000000 +0200
+++ postfix/postfix.spec	2004-08-25 21:00:30.000000000 +0200
@@ -28,6 +28,7 @@
 %define       V_tls          0.8.18-2.1.3-0.9.7d
 %define       V_pflogsumm    1.1.0
 %define       V_whoson       2.1.4
+%define       V_smtpd_patch  2.0.16-20031026
 
 #   package information
 Name:         postfix
@@ -40,7 +41,7 @@
 Group:        Mail
 License:      IPL
 Version:      %{V_postfix}
-Release:      2.1.2
+Release:      2.1.3
 
 #   package options
 %option       with_fsl       yes
@@ -50,6 +51,7 @@
 %option       with_ldap      no
 %option       with_whoson    no
 %option       with_fdsetsize no
+%option       with_smtpd_multiline_greeting no
 
 #   list of sources
 Source0:      ftp://ftp.porcupine.org/mirrors/postfix-release/official/postfix-%{V_postfix}.tar.gz
@@ -61,6 +63,7 @@
 Patch0:       postfix.patch
 Patch1:       postfix.patch.pfls
 Patch2:       ftp://ftp.openpkg.org/sources/CPY/postfix/postfix-%{V_whoson}-whoson.patch
+Patch3:       ftp://ftp.wl0.org/SOURCES/postfix-%{V_smtpd_patch}-multiline-greeting.patch
 
 #   build information
 Prefix:       %{l_prefix}
@@ -112,6 +115,7 @@
     o Optional MySQL support (see package options below)
     o Optional OpenLDAP support (see package options below)
     o Optional WHOSON support (see package options below)
+    o Optional SMTPD multiline greeting support
 
 %track
     prog postfix = {
@@ -134,10 +138,21 @@
         url       = ftp://ftp.openpkg.org/sources/CPY/postfix/
         regex     = postfix-(__VER__)-whoson.patch
     }
+    prog postfix:smtpd = {
+        version   = %{V_smtpd_patch}
+        url       = ftp://ftp.wl0.org/SOURCES/
+        regex     = postfix-(__VER__)-multiline-greeting.patch
+    }
 
 %prep
     #   unpack distribution files
     %setup -q
+
+    #   apply smtpd multiline greeting patch, see http://postfix.wl0.org/en/smtpd-multiline-banner
+%if "%{with_smtpd_multiline_greeting}" == "yes"
+    %patch3 -p1 -b .multiline
+%endif
+
 %if "%{with_ssl}" == "yes"
     %setup -q -T -D -a 1
 %endif
